Citation
--------

@Authors:

Julie Orjuela (IRD), Aurore Comte (IRD), Sébastien Ravel (CIRAD), Florian Charriat (INRAE), Tram Vi (IRD, AGI), Francois Sabot (IRD) and Sébastien Cunnac (IRD).

Useful notes
============

Before launching CulebrONT, you could basecall arbitrarily multiplexed libraries across several Minion runs with sequencing quality control and gather the output files by genome for subsequent steps. For that, you can use https://github.com/vibaotram/baseDmux.

Thanks
======

Thanks to Ndomassi Tando (i-Trop IRD) for his administration support.

The authors acknowledge the IRD i-Trop HPC (South Green Platform) from IRD Montpellier for providing HPC resources that contributed to this work. https://bioinfo.ird.fr/ - http://www.southgreen.fr

Thanks to Yann Delorme for this beautiful logo https://nimarell.github.io/resume

License
-------

Licenced under CeCill-C (http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html) and GPLv3
Intellectual property belongs to IRD and authors.
